The intent of this guide is to give you an idea about the Android development landscape and to help guide your learning if you are confused. Before we start, please note that the roadmap is opinionated, and you might have different opinions than those of the author. Having said that, [we would love to hear your opinions](https://github.com/kamranahmedse/roadmap.sh/issues/new) and incorporate them in the roadmap if suitable.

There are multiple ways to develop applications for the android; you can go down the path of hybrid application development where [flutter](https://flutter.dev/), [react-native](https://reactnative.dev/), or [NativeScript](https://www.nativescript.org/) are the most common contenders. Flutter uses Dart, whereas React Native and Native Script rely on JavaScript. Answering the question of hybrid vs native is out of the scope of this roadmap. This roadmap is focused on the native Android apps development but if you are interested in learning any hybrid framework, my personal preference is [react-native](https://reactnative.dev) and I would recommend you to checkout the [Frontend Developer Roadmap](/frontend).

## Complete Roadmap

Here is the full version of the roadmap in a single image and after that we have the broken down version with the resources and links to learn more about each of the boxes.

[![](/roadmaps/android/roadmap.svg)](/roadmaps/android/roadmap.png)

## Broken Down Version
Below is the broken down version of the roadmap with links and resources to learn more about each of the items listed in the complete roadmap above.

## Pick a Language
For the languages, you can develop android apps either by using Kotlin or Java.

[![](/roadmaps/android/pick-language.svg)](/roadmaps/android/pick-language.svg)

Although, you can use both [Kotlin](https://en.wikipedia.org/wiki/Kotlin_(programming_language)) and [Java](https://en.wikipedia.org/wiki/Java_(programming_language)) to develop native android apps, [Google announced in 2019](https://android-developers.googleblog.com/2019/05/google-io-2019-empowering-developers-to-build-experiences-on-Android-Play.html) to make Kotlin the preferred way of developing android applications. If you were to start learning android development today, Kotlin should be your language of choice.

## The Fundamentals
Install the [Android Studio](https://developer.android.com/studio) and learn the basics of Kotlin to get started. 

[![](/roadmaps/android/the-fundamentals.png)](/roadmaps/android/the-fundamentals.png)

We have also listed down some free resources which you can use for the items listed in the image above. If you have some better ones, please do suggest. Also, you don't need to go through all of them, just go through them and pick what you like.

* [Learn the basics of Kotlin](https://blog.teamtreehouse.com/absolute-beginners-guide-kotlin)
* [Kotlin Docs](https://kotlinlang.org/docs/reference/basic-syntax.html) and [Official Kotlin Tutorials](https://kotlinlang.org/docs/tutorials/)
* [Data Structures and Algorithms](https://www.studytonight.com/data-structures/introduction-to-data-structures). Also [check this](https://www.tutorialspoint.com/data_structures_algorithms/index.htm).
* [Kotlin DataStructures](https://kotlinlang.org/docs/reference/collections-overview.html)
* [Algorithms and DataStructures in Kotlin](https://github.com/bmaslakov/kotlin-algorithm-club)

## Version Control Systems
Version control systems record your changes to the codebase and allow you to recall specific versions later. There are multiple Version Control Systems available but [Git](https://git-scm.com/) is the most common one these days.

[![](/roadmaps/android/git-github.png)](/roadmaps/android/git-github.png)

Here are some of the resources to get you started. Feel free to google and find something else that you find easier.

* [Udacity — Version Control with Git](https://www.udacity.com/course/version-control-with-git--ud123)
* [GitHub Hello World](https://guides.github.com/activities/hello-world/)

## Building an Application

Here is the list of items that you are going to need when developing Android applications. Please note that, this is an exhaustive list, and you don't need to know it all from the get-go. Get an idea of the items listed, and just start building some apps and keep the items listed in the back of your mind and have a deep dive when using them. 

[![](/roadmaps/android/build-an-application.png)](/roadmaps/android/build-an-application.png)

To learn more about the items listed in the image above, here are the links to the relevant docs

* [Using Activities and Activity Life Cycles](https://developer.android.com/guide/components/activities/intro-activities)
* Building Flexible Interfaces using [Fragments](https://developer.android.com/guide/components/fragments)
* [Debugging using Android Studio Debugger](https://developer.android.com/studio/debug)
* [Handling App Configurations](https://developer.android.com/work/managed-configurations)
* [Using Intents and Intent Filters](https://developer.android.com/guide/components/intents-filters)
* [Understand Context](https://guides.codepath.com/android/Using-Context)
* [Learn about Multithreading](https://developer.android.com/training/multiple-threads)
* [Data Privacy](https://www.raywenderlich.com/6901838-data-privacy-for-android)
* [Securing Network Data](https://www.raywenderlich.com/5634-securing-network-data-tutorial-for-android)
* [Dependency Injection](https://developer.android.com/training/dependency-injection)
* [Content Providers](https://developer.android.com/guide/topics/providers/content-providers)
* [Glide](https://github.com/bumptech/glide), [Retrofit](https://square.github.io/retrofit/), [Crashlytics](https://firebase.google.com/docs/crashlytics/get-started), [GSON](https://github.com/google/gson)
* [Room](https://developer.android.com/topic/libraries/architecture/room), [Navigation](https://developer.android.com/guide/navigation/navigation-getting-started), [Work Manager](https://developer.android.com/topic/libraries/architecture/workmanager), [LiveData](https://developer.android.com/topic/libraries/architecture/livedata), [Data Binding](https://developer.android.com/topic/libraries/data-binding)
* [RxJava](https://github.com/ReactiveX/RxJava), [RxKotlin](https://github.com/ReactiveX/RxKotlin)
* [Memory Management Overview](https://developer.android.com/topic/performance/memory-overview)
* [Diving deeper into context-oriented programming in Kotlin](https://proandroiddev.com/diving-deeper-into-context-oriented-programming-in-kotlin-3ecb4ec38814)  

I would highly recommend watching [this free course](https://www.udacity.com/course/developing-android-apps-with-kotlin--ud9012) from google on Developing Android Apps with Kotlin. Also, here are some of the resources to learn more about the topics listed above.

* [Developing Android Apps with Kotlin](https://www.udacity.com/course/developing-android-apps-with-kotlin--ud9012)
* [Android Developer Guides](https://developer.android.com/guide)
* [Raywenderlich](https://www.raywenderlich.com)

## Wrap Up

That wraps it up for the android developer roadmap. Again, remember to not be exhausted by the list; just learn the basics and start working on some project, rest of the learnings will come along the way. Good luck!
 
For any suggestions, improvements and feedback, feel free to [submit an issue](https://github.com/kamranahmedse/roadmap.sh) or reach out to me on twitter [@kamranahmedse](https://twitter.com/kamranahmedse).

<!-- @fixme add padding to the container -->
<br /><br /><br />
